disp(' ');
disp(' liftoff.m, ver 1.0,	April 19, 2005 ');
disp(' Rocket Vehicle Liftoff Acoustics and Skin Vibration ');
disp(' By Tom Irvine  Email: tomirvine@aol.com');
disp(' ');
disp(' References:  ');
disp(' 1.  Acoustic Loads Generated by the Propulsion System. ');
disp(' NASA SP-8072, Monograph N71-33195, 1971. ');
disp(' 2.  Wilby & Wilby, Prediction of External Acoustic Field');
disp(' on Taurus During Liftoff, AARC No. 121, 1991. ');
%
clear amp;
clear samp;
clear sn;
clear nrspl;
clear f;
clear freq;
clear Lwb;
%
clear sns;
clear asap;
clear spl;
clear an;
clear dn;
clear fr;
clear ar;
%
clear s;
clear psd;
%
MAX=100;
%
TPI=2.*pi;
%
ref  = 1.0e-12;
Aref = 20.e-06;
m_per_ft = 0.3048;
%
%   step 1
%
[isys,F,U,dei,aceff,cspeed,N,iw] = liftoff_input_data(m_per_ft);
%
%   step 2
%
WOA=0.5*aceff*N*F*U;
out1=sprintf('\n  Overall acoustic power WOA = %12.3g Watts\n ',WOA); 
disp(out1);
%
%   step3 
%
LW=120. + 10.*log10(WOA);
out1=sprintf('\n  Overall acoustic power level LW = %12.4g dB ',LW);
disp(out1);
disp('  Ref = 1.0e-12 Watts ');
%
%   step4
%
de=sqrt(N)*dei;
%
%   step 5
%
[sn,nrspl,Lwb,ilast,f,freq,num]=liftoff_step5(de,U,ref,LW);
%
%   step6
%
[stationdiam,samp,igeo,xs,x1,rho]= liftoff_step6(isys,ilast,de,U,freq,ref,m_per_ft,num);
%
%   step7
%
[spl,strouhal,r,theta,DI,beta_rad]=liftoff_step7(freq,de,U,samp,Lwb,ilast,igeo,xs,iw,stationdiam,cspeed,x1,rho);
%
%   step8
%
if(iw==1)
   [spl,delta]=liftoff_step8(spl,freq,stationdiam,cspeed,beta_rad);
else
    mmm=length(spl);
    delta=zeros(1, mmm);
    delta=delta';
end
%
%   step 9   apply smoothing (conservative)
%
for(i=1:length(spl))
    if(i>=2 )  
        if(spl(i-1)-spl(i) > 4.5)
            spl(i)=spl(i-1)-4.5;
        end
    end
end    
%
sum=0.;
%
disp(' ');
disp('    freq(Hz)  Strouhal   Lwb(dB)    Source(m)    r(m)    theta(deg)  DI(dB)   delta(dB)  SPL(dB) ');
iii=length(spl);
for(i=1:iii)
		ap=(Aref)*( 10.^((spl(i))/20.));
		sum=sum+(ap^2.);
%
        out1=sprintf(' %9.4g  %9.4f  %9.1f  %9.4f  %9.4f  %9.4f  %9.3f  %9.2f  %9.1f',freq(i),strouhal(i),Lwb(i),samp(i),r(i),theta(i),DI(i),delta(i),spl(i));
        disp(out1);
%       
end
disp(' ');
%
sum=sqrt(sum);
sum=20.*log10(sum/Aref);
%
out1=sprintf('\n Overall SPL = %12.4g dB   ref 20 micro Pa \n\n',sum);
disp(out1);
%
disp(' Plot SPL?');
disp(' 1=yes 2=no ');
ip=input(' ');
if(ip==1)
    plot(freq,spl);
    out1=sprintf(' One-third Octave SPL   Overall Level = %7.1f dB  ',sum);
    title(out1);
    xlabel('Center Frequency (Hz)');
    ylabel('SPL (dB)'); 
    set(gca,'MinorGridLineStyle','none','GridLineStyle',':','XScale','log','YScale','lin');  
    grid; 
end
%%%
disp(' ')
disp(' Write the SPL to text file? ')
choice=input(' 1=yes   2=no  ' );
disp(' ')
if choice == 1 
        disp(' Enter output filename ');
        PSD_filename = input(' ','s');
        disp(' ')
        disp(' Output units:  freq(Hz)  &  SPL(dB) ');
%
        jnum = length(f);
        fid = fopen(PSD_filename,'w');
        for j=1:jnum
            fprintf(fid,'%7.2f %11.4g \n',freq(j),spl(j));
        end
        fclose(fid);
end
%%%
disp(' ');
disp(' Calculate resulting vibration via the Franken method? '); 
disp(' 1=yes 2=no ');
%
ifm=input(' ');
%
if(ifm==1)
    [f,apsd,grms,sdiam]=liftoff_Franken(freq,spl,stationdiam);
%
    disp(' ')
    disp(' Write the PSD to text file? ')
    choice=input(' 1=yes   2=no  ' );
    disp(' ')
    if choice == 1 
        disp(' Enter output filename ');
        PSD_filename = input(' ','s');
        disp(' ')
        disp(' Output units:  freq(Hz)  &  Accel(G^2/Hz) ');
%
        jnum = length(f);
        fid = fopen(PSD_filename,'w');
        for j=1:jnum
            fprintf(fid,'%7.2f %11.4g \n',f(j),apsd(j));
        end
        fclose(fid);
    end
end
%
disp(' ')
disp(' Write the complete output data to text file? ')
choice=input(' 1=yes   2=no  ' );
disp(' ')
if choice == 1 
    disp(' Enter output filename ');
    Out_filename = input(' ','s');
    fid = fopen(Out_filename,'w');  
%
    fprintf(fid,'\n liftoff.m, ver 1.0,	April 19, 2005 \n');
    fprintf(fid,' Rocket Vehicle Liftoff Acoustics and Skin Vibration \n');
    fprintf(fid,' By Tom Irvine  Email: tomirvine@aol.com\n\n');
%
    fprintf(fid,' References:  \n');
    fprintf(fid,' 1.  Acoustic Loads Generated by the Propulsion System. \n');
    fprintf(fid,' NASA SP-8072, Monograph N71-33195, 1971. \n');
    fprintf(fid,' 2.  Wilby & Wilby, Prediction of External Acoustic Field\n');
    fprintf(fid,' on Taurus During Liftoff, AARC No. 121, 1991. \n\n');
%
    fprintf(fid,'              Thrust = %10.4g lbf     \n',F/4.4484);
    fprintf(fid,'                     = %10.4g N       \n\n',F);   
%   
    fprintf(fid,'    Exhaust velocity = %10.4g ft/sec  \n',U/m_per_ft);   
    fprintf(fid,'                     = %10.4g m/sec  \n\n',U);      
%
    fprintf(fid,' Acoustic Efficiency = %10.4g     \n\n',aceff);
%
    fprintf(fid,'   Number of Nozzles = %d     \n\n',N);
%
    fprintf(fid,'    Nozzle Diameter = %10.4g inch    \n',dei*12/m_per_ft); 
    fprintf(fid,'                    = %10.4g m       \n\n',dei); 
%     
    fprintf(fid,'   Station Diameter = %10.4g inch    \n',sdiam*12.); 
    fprintf(fid,'                    = %10.4g m       \n\n',sdiam*m_per_ft);    
%     
    fprintf(fid,'  Station Length above Nozzle Exit Plane = %10.4g inch    \n',xs*12./m_per_ft); 
    fprintf(fid,'                                         = %10.4g m       \n\n',xs);    
%   
  	if(igeo==4 | igeo==5)  
	    fprintf(fid,' Distance from nozzle exit to ground = %10.4g inch \n',x1*12/m_per_ft);           
	    fprintf(fid,'                                     = %10.4g m \n\n',x1);
%
        fprintf(fid,' Angle rho from deflected exhaust = %4.2f deg \n\n',rho);
%
    end
%
if(igeo==1)
     fprintf(fid,'\n Single nozzle, undeflected (Smith & Brown) \n');
end
if(igeo==2)
     fprintf(fid,'\n Single nozzle, undeflected (Morgan & Young) \n');
end    
if(igeo==3)
     fprintf(fid,'\n Multiple nozzles, undeflected \n');
end    
if(igeo==4)
     fprintf(fid,'\n Deflected, open scoop \n');
end    
if(igeo==5)
     fprintf(fid,'\n Deflected, closed bucket \n');
end
%
if(iw==1)
     fprintf(fid,'\n Wilby correction applied. \n\n');
end
%
    fprintf(fid,'\n Overall acoustic power WOA = %12.4g Watts\n ',WOA); 
%    
    fprintf(fid,'\n Overall SPL = %12.4g dB   ref 20 micro Pa \n\n',sum);
%    
    jnum = length(spl);
    fprintf(fid,'    freq(Hz)  Strouhal   Lwb(dB)    Source(m)    r(m)    theta(deg)  DI(dB)   delta(dB)  SPL(dB) \n'); 
    for i=1:jnum
            fprintf(fid,' %9.4g  %9.4f  %9.1f  %9.2f  %9.2f  %9.2f  %9.3f  %9.2f  %9.1f \n',freq(i),strouhal(i),Lwb(i),samp(i),r(i),theta(i),DI(i),delta(i),spl(i)); 
    end
    fclose(fid);
end