function [f,apsd,grms,sdiam]=liftoff_Franken(freq,spl,stationdiam);
%
%   liftoff_Franken.m, ver 1.0,	April 19, 2005 
%
disp(' ')
disp('Cylindrical Skin Vibration due to Acoustic Pressure Field ')
disp('Franken upper limit curve is used per NASA CR-1302 ')
%
TPI=2.*pi;
%
ref  = 1.0e-12;
Aref = 20.e-06;
%
m_per_ft = 0.3048;
%
clear f;
clear fr;
clear ar;
clear s;
clear psd;
clear E;
%
f=freq;
fmax=max(freq);
ilast=length(spl);
%
%**************************************************************************
%
    sdiam=stationdiam/m_per_ft;
%    
    cref=200000./12.;
%
    disp(' ')
	disp(' Enter material:  1=aluminum  2=steel  3=titanium  4=other ')
    imat=input(' ');
%
    if(imat ~=1 & imat ~=2 & imat ~= 3)
		imat=4;
    end
%
	if(imat==1)
		W=0.1;
		cmat=cref;
    end
	if(imat==2)
		W=0.29;
		cmat=cref;
    end
	if(imat==3)
		W=0.163;
		cmat=1.6e+04;
    end    
    if(imat==4)
%
		disp(' Enter cylindrical skin weight density (lbm/in^3) ');
   		W=input(' ');
%
		disp(' Enter elastic modulus (lbf/in^2) ');
   		E=input(' ');
%
		cmat = sqrt( (E/W)*(32.2/12.) );
%
    end
%
	out1=sprintf('\n Weight Density = %10.3g lbm/in^3 ',W);
    disp(out1)
%
	out1=sprintf('\n\n Speed of Sound in Material = %10.3g ft/sec ',cmat);	
    disp(out1)
%
	W=W*(12.^3);
%
	scale = cmat/cref;
%
%**************************************************************************
%	
	disp(' Enter skin thickness (in) ');
   	thickness=input(' ')
% 
    thickness=thickness/12.;
%
    W=W*thickness;
%
	out1=sprintf(' Weight Density (per area) = %12.3f lbm/ft^2 ',W);
    disp(out1)
%
	fr(1)=1.0;
	fr(2)=2.0;
	fr(3)=2.7;
	fr(4)=3.0;
	fr(5)=3.3;
	fr(6)=3.6;
	fr(7)=3.7;
	fr(8)=3.78;
	fr(9)=3.9;
	fr(10)=4.0;
	fr(11)=4.1;
	fr(12)=4.3;
	fr(13)=4.7;
%
	ar(1)=-158;	
	ar(2)=-146;
	ar(3)=-140.5;
	ar(4)=-136.;
	ar(5)=-130.;
	ar(6)=-121.;
	ar(7)=-119.;
	ar(8)=-118.8;
	ar(9)=-119.;
	ar(10)=-120.;
	ar(11)=-121.7;
	ar(12)=-123.;
	ar(13)=-124.5;
%
	for(i=1:13)
		fr(i)= log10( ((10.^fr(i))*scale) );
    end
%
	jlast = 13;
%
for(i=1:ilast)
%
		sfr = log10( f(i)*sdiam );
%
        if( sfr <= fr(1))
			va= ar(1);
        end
		if(sfr >= fr(jlast) )
			va= ar(jlast);
        end
		if( sfr > fr(1) && sfr < fr(jlast) )
%
			for(j=1:11)
%
				if(sfr >= fr(j) && sfr <= fr(j+1) )
%
					len = fr(j+1) -fr(j);
					k2  = (sfr    -fr(j))/len;
%
					k1=1.-k2;
					va = k1*ar(j) + k2*ar(j+1);
%
					break;
                end
            end
        end
%
		vdb = va - 20.*log10(W) + spl(i);
%
		al = 1.*(10.^(vdb/20.));
%
		df = ((2.^(1./6.))-1./(2.^(1./6.)))*f(i);
%
% assume vdb is in terms of RMS
%
		psd(i) = (al^2.)/df;
%
end
%
ra=0.;
rb=0.;
%
for(i=1:(ilast-1))
%
    s(i)=log( psd(i+1)/psd(i) )/log( f(i+1)/f(i) );
%
    if(s(i) < -1.0001 ||  s(i) > -0.9999 )
%  
    rb=rb+ ( psd(i+1) * f(i+1)- psd(i)*f(i))/( s(i)+1.);
%
else
%
    rb=rb+ psd(i)*f(i)*log( f(i+1)/f(i));
end
%		 
    if(f(i) < 2050.)
        ra=rb;
    end
end
%
grms=sqrt(ra);
grmsb=sqrt(rb);
%
out1=sprintf('\n Ring Frequency = %12.4g Hz ',cmat/(pi*sdiam));
disp(out1)
%
out1=sprintf('\n\n Overall Skin Vibration Level (up to 2000 Hz) = %12.4g GRMS ',grms );
disp(out1)
%
out1=sprintf('\n Overall Skin Vibration Level (up to 10,000 Hz) = %12.4g GRMS\n',grmsb );
disp(out1)
%
disp(' ');
disp(' Plot the PSD? ')
choice = input(' 1=yes 2=no ');
%
if(choice == 1)
    figure(1);     
    plot(f,psd)
    xlabel(' Frequency (Hz)');
    ylabel(' Accel (G^2/Hz)'); 
    at = sprintf(' Power Spectral Density  Overall Level = %6.3g GRMS ',grmsb);   
    title(at);
    set(gca,'MinorGridLineStyle','none','GridLineStyle',':','XScale','log','YScale','log'); 
    grid;
    psd_max=max(psd);
    psd_min=min(psd); 
%    
    if(psd_max < 10000)
        ymax=10000;
    end
    if(psd_max < 1000)
        ymax=1000;
    end
    if(psd_max < 100)
        ymax=100;
    end
    if(psd_max < 10)
        ymax=10;
    end
    if(psd_max < 1)
        ymax=1;
    end
    if(psd_max < 0.1)
        ymax=0.1;
    end
    if(psd_max < 0.01)
        ymax=0.01;
    end
    if(psd_max < 0.001)
        ymax=0.001;
    end
    if(psd_max < 0.0001)
        ymax=0.0001;
    end
    if(psd_max < 0.00001)
        ymax=0.00001;
    end
%
    ymin=ymax/100;    
    if(psd_min < psd_max/1000)
       ymin=ymax/1000;    
    end 
    if(psd_min < psd_max/1000)
       ymin=ymax/1000;    
    end    
%
    pfmax=fmax;
    fmin=10;
    axis([fmin,pfmax,ymin,ymax]);  
%
end
apsd=psd;